@@ -2,7 +2,7 @@
 
 ;; curses.scm
 
-;; Copyright 2009, 2010, 2011 Free Software Foundation, Inc.
+;; Copyright 2009, 2010, 2011, 2013 Free Software Foundation, Inc.
 
 ;; This file is part of GNU Guile-Ncurses.
 
@@ -466,6 +466,9 @@
             right
             right-off
             right-on
+            set-xchar-attr!
+            set-xchar-color!
+            set-xchar-chars!
             standout
             standout-off
             standout-on
@@ -474,11 +477,13 @@
             top-on
             underline
             underline-on
-            underlline-off
+            underline-off
             vertical
             vertical-off
             vertical-on
             xchar?
+            xchar-attr
+            xchar-color
             xchar-chars
             ))
 
@@ -617,9 +622,9 @@ name of the character as as string."
 (define xchar-attr (record-accessor rtd-xchar 'attr))
 (define xchar-color (record-accessor rtd-xchar 'color))
 (define xchar-chars (record-accessor rtd-xchar 'chars))
-(define set-xchar-attr! (record-modifier rtd-xchar 'attr))
-(define set-xchar-color! (record-modifier rtd-xchar 'color))
-(define set-xchar-chars! (record-modifier rtd-xchar 'chars))
+(define %set-xchar-attr! (record-modifier rtd-xchar 'attr))
+(define %set-xchar-color! (record-modifier rtd-xchar 'color))
+(define %set-xchar-chars! (record-modifier rtd-xchar 'chars))
 
 (define (xchar->list x)
   "Converts a complex charater X to a list of properties"
@@ -1163,6 +1168,13 @@ not modified, but the color pair, if any, is modified."
   (syntax-rules ()
     ((_ val)
      (typecheck val 'integer integer? exact?))))
+(define-syntax assert-list-of-chars
+  (syntax-rules ()
+    ((_ loc)
+     (if (or (not (list? loc)) (not (every char? loc)))
+         (raise (condition (&curses-wrong-type-arg-error
+                            (arg str)
+                            (expected-type 'list))))))))
 (define-syntax assert-pad
   (syntax-rules ()
     ((_ val)
@@ -1194,6 +1206,24 @@ not modified, but the color pair, if any, is modified."
                             (arg str)
                             (expected-type 'xstring))))))))
 
+(define (set-xchar-attr! ch attr)
+  "Directly set the attributes for a complex character"
+  (assert-xchar ch)
+  (assert-integer attr)
+  (%set-xchar-attr! ch attr))
+
+(define (set-xchar-color! ch color-pair-number)
+  "Directly set the color pair number for a complex character"
+  (assert-xchar ch)
+  (assert-integer color-pair-number)
+  (%set-xchar-color! ch color-pair-number))
+
+(define (set-xchar-chars! ch list-of-chars)
+  "Directly set the character(s) for a complex character"
+  (assert-xchar ch)
+  (assert-list-of-chars list-of-chars)
+  (%set-xchar-chars! ch list-of-chars))
+
 ;; Scheme calling wrappers for C functions
 
 (define* (addch win ch #:key y x)
@@ -1312,7 +1342,7 @@ the color pair given by COLOR."
       (%wattr-set! win attr (pair-number attr))))
 
 (define (baudrate)
-  "Returns the baudrate of this terminal"
+  "Returns the baudrate of this terminal, or #f on failure."
   (%baudrate))
 
 (define (beep)
@@ -1389,8 +1419,8 @@ character, the default lines will be used."
              (xchar->list (normal-on (acs-llcorner))) (xchar->list (normal-on (acs-lrcorner))))))
 
 (define (can-change-color?)
-  "Returns #t if the terminal can change the RGB of a color number, or #f if
-the terminal has preassigned, unmodifiable colors."
+  "Returns #t if the terminal can change the RGB of a color number, or
+#f if the terminal has preassigned, unmodifiable colors."
   (%can-change-color?))
 
 (define (cbreak!)
@@ -1443,8 +1473,9 @@ scratch."
 
 (define (color-content c)
   "Given a color number, this procedure returns a three-element list
-containing the red, green, and blue values of the color on a 0 to 1000 scale.
-It can return #f if the color is out of range or colors aren't initialized."
+containing the red, green, and blue values of the color on a 0 to 1000
+scale.  It can return #f if the color is out of range or colors aren't
+initialized."
   (assert-integer c)
   (%color-content c))  
 
@@ -1476,16 +1507,16 @@ of WIN."
 (define (copywin srcwin destwin sminrow smincol dminrow dmincol
 		 dmaxrow dmaxcol overlay)
   "This routine copies text from SRCWIN to DESTWIN.  A rectangle is
-specified in the destination window DMINROW DMINCOL to DMAXROW DMAXCOL, and 
-the upper-left-corner of the source window is specified SMINROW and SMINCOL.
-If OVERLAY is 1, only text and not blanks are copied.  If overlay is 0,
-text and blanks are copied.  Returns #t on success. or #f on failure.  Failure
-usually indicates a problem with your coordinates."
+specified in the destination window DMINROW DMINCOL to DMAXROW
+DMAXCOL, and the upper-left-corner of the source window is specified
+SMINROW and SMINCOL.  If OVERLAY is #t, only text and not blanks are
+copied.  If overlay is #f, text and blanks are copied.  Returns #t on
+success. or #f on failure.  Failure usually indicates a problem with
+your coordinates."
   (assert-window srcwin)
   (assert-window destwin)
   (for-each (lambda (x) (assert-integer x))
-            (list sminrow smincol dminrow dmincol dmaxrow dmaxcol
-                  overlay))
+            (list sminrow smincol dminrow dmincol dmaxrow dmaxcol))
   (%copywin srcwin destwin sminrow smincol dminrow dmincol dmaxrow dmaxcol
 	    overlay))
 
