@@ -1,7 +1,7 @@
 /*
   extra_const.c
 
-  Copyright 2010 Free Software Foundation, Inc.
+  Copyright 2010, 2011 Free Software Foundation, Inc.
 
   This file is part of GNU Guile-Ncurses.
 
@@ -23,7 +23,9 @@
 #include <config.h>
 
 #include <libguile.h>
+#ifdef ENABLE_TERMIOS
 #include <termios.h>
+#endif
 
 #if HAVE_CURSES_H
 #include <curses.h>
@@ -38,6 +40,8 @@
 #include "compat.h"
 #include "extra_const.h"
 
+#ifdef ENABLE_TERMIOS
+
 SCM gucu_BS0;
 SCM gucu_BS1;
 SCM gucu_BSDLY;
@@ -78,9 +82,7 @@ SCM gucu_TCSANOW;
 SCM gucu_VT0;
 SCM gucu_VT1;
 SCM gucu_VTDLY;
-#if HAVE_DECL_XCASE
 SCM gucu_XCASE;
-#endif
 
 SCM gucu_NCCS;
 
@@ -134,17 +136,13 @@ SCM gucu_ECHOE;
 SCM gucu_ECHOK;
 SCM gucu_ECHOKE;
 SCM gucu_ECHONL;
-#if HAVE_DECL_ECHOPRT
 SCM gucu_ECHOPRT;
-#endif
 SCM gucu_FLUSHO;
 SCM gucu_ICANON;
 SCM gucu_IEXTEN;
 SCM gucu_ISIG;
 SCM gucu_NOFLSH;
-#if HAVE_DECL_PENDIN
 SCM gucu_PENDIN;
-#endif
 SCM gucu_TOSTOP;
 
 SCM gucu_B0;
@@ -165,25 +163,58 @@ SCM gucu_B75;
 SCM gucu_B9600;
 
 #define D(x) gucu_ ## x = scm_permanent_object(scm_c_define(#x, scm_from_int(x)))
+#define F(x) gucu_ ## x = scm_permanent_object(scm_c_define(#x, SCM_BOOL_F))
 
 void
 gucu_extra_init_const ()
 {
-  D(BS0);
-  D(BS1);
-  D(BSDLY);
-  D(CR0);
-  D(CR1);
-  D(CR2);
-  D(CR3);
-  D(CRDLY);
-  D(FF0);
-  D(FF1);
-  D(FFDLY);
+#if HAVE_DECL_BS0
+  D(BS0);			/* XOPEN */
+  D(BS1);			/* XOPEN */
+  D(BSDLY);			/* XOPEN */
+  D(CR0);			/* XOPEN */
+  D(CR1);			/* XOPEN */
+  D(CR2);			/* XOPEN */
+  D(CR3);			/* XOPEN */
+  D(CRDLY);			/* XOPEN */
+  D(FF0);			/* XOPEN */
+  D(FF1);			/* XOPEN */
+  D(FFDLY);			/* XOPEN */
+  D(NL0);			/* XOPEN */
+  D(NL1);			/* XOPEN */
+  D(NLDLY);			/* XOPEN */
+  D(TAB1);			/* XOPEN */
+  D(TAB2);			/* XOPEN */
+  D(TAB3);			/* XOPEN */
+  D(TABDLY);			/* XOPEN */
+#else
+  F(BS0);			/* XOPEN */
+  F(BS1);			/* XOPEN */
+  F(BSDLY);			/* XOPEN */
+  F(CR0);			/* XOPEN */
+  F(CR1);			/* XOPEN */
+  F(CR2);			/* XOPEN */
+  F(CR3);			/* XOPEN */
+  F(CRDLY);			/* XOPEN */
+  F(FF0);			/* XOPEN */
+  F(FF1);			/* XOPEN */
+  F(FFDLY);			/* XOPEN */
+  F(NL0);			/* XOPEN */
+  F(NL1);			/* XOPEN */
+  F(NLDLY);			/* XOPEN */
+  F(TAB1);			/* XOPEN */
+  F(TAB2);			/* XOPEN */
+  F(TAB3);			/* XOPEN */
+  F(TABDLY);			/* XOPEN */
+#endif
+
+#if HAVE_DECL_XCASE
+  D(XCASE);			/* XOPEN */
+#else
+  F(XCASE);
+#endif
+
   D(IUCLC);
-  D(NL0);
-  D(NL1);
-  D(NLDLY);
   D(OCRNL);
   D(OFDEL);
   D(OFILL);
@@ -192,10 +223,6 @@ gucu_extra_init_const ()
   D(ONLRET);
   D(ONOCR);
   D(OPOST);
-  D(TAB1);
-  D(TAB2);
-  D(TAB3);
-  D(TABDLY);
   D(TCIFLUSH);
   D(TCIOFF);
   D(TCIOFLUSH);
@@ -209,9 +236,6 @@ gucu_extra_init_const ()
   D(VT0);
   D(VT1);
   D(VTDLY);
-#if HAVE_DECL_XCASE
-  D(XCASE);
-#endif
 
   D(NCCS);
 
@@ -260,24 +284,35 @@ gucu_extra_init_const ()
   D(VTIME);
 
   D(ECHO);
-  D(ECHOCTL);
-  D(ECHOE);
+  D(ECHOE);			
   D(ECHOK);
-  D(ECHOKE);
   D(ECHONL);
-#if HAVE_DECL_ECHOPRT
-  D(ECHOPRT);
-#endif
-  D(FLUSHO);
   D(ICANON);
   D(IEXTEN);
   D(ISIG);
   D(NOFLSH);
-#if HAVE_DECL_PENDIN
-  D(PENDIN);
-#endif
   D(TOSTOP);
 
+#if HAVE_DECL_ECHOCTL
+  D(ECHOCTL);			/* BSD/SVID */
+  D(ECHOKE);			/* BSD/SVID */
+  D(FLUSHO);			/* BSD/SVID */
+#else
+  F(ECHOCTL);			/* BSD/SVID */
+  F(ECHOKE);			/* BSD/SVID */
+  F(FLUSHO);			/* BSD/SVID */
+#endif
+#if HAVE_DECL_ECHOPRT
+  D(ECHOPRT);			/* BSD/SVID */
+#else
+  F(ECHOPRT);			/* BSD/SVID */
+#endif
+#if HAVE_DECL_PENDIN
+  D(PENDIN);			/* BSD/SVID */
+#else
+  F(PENDIN);			/* BSD/SVID */
+#endif
+
   D(B0);
   D(B110);
   D(B1200);
@@ -295,3 +330,10 @@ gucu_extra_init_const ()
   D(B75);
   D(B9600);
 }
+
+#else /* !ENABLE_TERMIOS */
+void
+gucu_extra_init_const ()
+{
+}
+#endif
