@@ -1,7 +1,7 @@
 /*
   extra_func.c
 
-  Copyright 2010 Free Software Foundation, Inc.
+  Copyright 2010, 2011 Free Software Foundation, Inc.
 
   This file is part of GNU Guile-Ncurses.
 
@@ -22,22 +22,24 @@
 
 #include <config.h>
 
-#define _GNU_SOURCE
 #include <assert.h>
 #include <libguile.h>
 #include <sys/types.h>
-#include <termios.h>
 #ifdef GUILE_CHARS_ARE_UCS4
 #include <uniwidth.h>
 #else
 #include <wchar.h>
 #endif
+#ifdef ENABLE_TERMIOS
+#include <termios.h>
+#endif
 
 #include "compat.h"
 #include "extra_func.h"
 #include "extra_type.h"
 #include "type.h"
 
+#ifdef ENABLE_TERMIOS
 SCM
 gucu_cfgetispeed (SCM s_termios)
 {
@@ -122,6 +124,77 @@ SCM gucu_cfsetospeed_x (SCM s_termios, SCM s_speed)
   return SCM_UNSPECIFIED;
 }
 
+#ifdef HAVE_GRANTPT
+/* If FD is the file descriptor of a master pseudo-terminal, this
+   changes the mode and permissions of the slave pseudo-terminal
+   so that it can be used.  */
+SCM
+gucu_grantpt (SCM fd)
+{
+  int c_fd;
+  int ret;
+
+  SCM_ASSERT (scm_is_integer (fd), fd, SCM_ARG1, "grantpt");
+  c_fd = scm_to_int (fd);
+  ret = grantpt (c_fd);
+  if (ret == -1)
+    scm_syserror ("grantpt");
+
+  return SCM_UNSPECIFIED;
+}
+#endif
+
+
+/* IF FD is a file descriptor of a pseudo-terminal device,
+   this sets that pseudoterminal to RAW mode. */
+SCM
+gucu_ptsmakeraw (SCM fd)
+{
+  int c_fd;
+  int ret;
+  struct termios terminal_attributes;
+
+  SCM_ASSERT (scm_is_integer (fd), fd, SCM_ARG1, "ptsmakeraw");
+
+  c_fd = scm_to_int (fd);
+  ret = tcgetattr (c_fd, &terminal_attributes);
+  if (ret == -1)
+    scm_syserror ("ptsmakeraw");
+  terminal_attributes.c_iflag &= ~(IGNBRK | BRKINT | PARMRK | ISTRIP
+				   | INLCR | IGNCR | ICRNL | IXON);
+  terminal_attributes.c_oflag &= ~OPOST;
+  terminal_attributes.c_lflag &= ~(ECHO | ECHONL | ICANON | ISIG | IEXTEN);
+  terminal_attributes.c_cflag &= ~(CSIZE | PARENB);
+  terminal_attributes.c_cflag |= CS8;
+  ret = tcsetattr (c_fd, TCSANOW, &terminal_attributes);
+  if (ret == -1)
+    scm_syserror ("ptsmakeraw");
+  return SCM_UNDEFINED;
+}
+
+#ifdef HAVE_PTSNAME
+/* If FD, a file descriptor, is a master pseudo-terminal device, this
+   returns a string that contains the name of the slave
+   pseudo-terminal device.  */
+SCM
+gucu_ptsname (SCM fd)
+{
+  int c_fd;
+  char *name;
+
+  SCM_ASSERT (scm_is_integer (fd), fd, SCM_ARG1, "ptsname");
+
+  c_fd = scm_to_int (fd);
+  name = ptsname (c_fd);
+  if (name == NULL)
+    return SCM_BOOL_F;
+
+  return scm_from_locale_string (name);
+}
+#endif
+
+
+
 SCM gucu_tcdrain (SCM s_fd_or_port)
 {
   SCM s_fd;
@@ -447,12 +520,32 @@ gucu_termios_cc_set_x (SCM s_termios, SCM s_pos, SCM s_char)
   return SCM_UNSPECIFIED;
 }
 
+#ifdef HAVE_UNLOCKPT
+/* If FD is the file descriptor of a master pseudo-terminal, this
+   changes the mode and permissions of the slave pseudo-terminal
+   so that it can be used.  */
+SCM
+gucu_unlockpt (SCM fd)
+{
+  int ret;
+  SCM_ASSERT (scm_is_integer (fd), fd, SCM_ARG1, "unlockpt");
+  ret = unlockpt (scm_to_int (fd));
+  if (ret == -1)
+    scm_syserror ("unlockpt");
+
+  return SCM_UNSPECIFIED;
+}
+#endif
+
+#endif /* ENABLE_TERMIOS */
+
 /* Return the number of character cells that string requires */
 SCM
 gucu_strwidth (SCM str)
 {
 #ifdef GUILE_CHARS_ARE_UCS4
-  size_t i, len, siz;
+  SCM s_siz;
+  size_t i, len;
   uint32_t *s;
 
   SCM_ASSERT (scm_is_string (str), str, SCM_ARG1, "%strwidth");
@@ -461,9 +554,9 @@ gucu_strwidth (SCM str)
   for (i = 0; i < len; i ++)
     s[i] = SCM_CHAR (scm_c_string_ref (str, i));
   s[len] = 0;
-  siz = scm_from_int (u32_strwidth (s, "UTF-8"));
+  s_siz = scm_from_int (u32_strwidth (s, "UTF-8"));
   free (s);
-  return siz;
+  return s_siz;
 #else
   size_t i, len, s, siz;
 
@@ -483,6 +576,7 @@ gucu_strwidth (SCM str)
 void
 gucu_extra_init_function ()
 {
+#ifdef ENABLE_TERMIOS
   scm_c_define_gsubr ("cfgetispeed", 1, 0, 0, gucu_cfgetispeed);
   scm_c_define_gsubr ("cfgetospeed", 1, 0, 0, gucu_cfgetospeed);
   scm_c_define_gsubr ("cfmakeraw!", 1, 0, 0, gucu_cfmakeraw_x);
@@ -491,6 +585,13 @@ gucu_extra_init_function ()
   scm_c_define_gsubr ("cfsetspeed!", 2, 0, 0, gucu_cfsetspeed_x);
 #endif
   scm_c_define_gsubr ("cfsetospeed!", 2, 0, 0, gucu_cfsetospeed_x);
+#ifdef HAVE_GRANTPT
+  scm_c_define_gsubr ("grantpt", 1, 0, 0, gucu_grantpt);
+#endif
+  scm_c_define_gsubr ("ptsmakeraw", 1, 0, 0, gucu_ptsmakeraw);
+#ifdef HAVE_PTSNAME
+  scm_c_define_gsubr ("ptsname", 1, 0, 0, gucu_ptsname);
+#endif
   scm_c_define_gsubr ("tcdrain", 1, 0, 0, gucu_tcdrain);
   scm_c_define_gsubr ("tcflow", 2, 0, 0, gucu_tcflow);
   scm_c_define_gsubr ("tcflush", 2, 0, 0, gucu_tcflush);
@@ -500,7 +601,9 @@ gucu_extra_init_function ()
 #endif
   scm_c_define_gsubr ("tcsendbreak", 2, 0, 0, gucu_tcsendbreak);
   scm_c_define_gsubr ("tcsetattr!", 3, 0, 0, gucu_tcsetattr_x);
-  scm_c_define_gsubr ("%strwidth", 1, 0, 0, gucu_strwidth);
+#ifdef HAVE_UNLOCKPT
+  scm_c_define_gsubr ("unlockpt", 1, 0, 0, gucu_unlockpt);
+#endif
 
   scm_c_define_gsubr ("termios-iflag", 1, 0, 0, gucu_termios_iflag);
   scm_c_define_gsubr ("termios-oflag", 1, 0, 0, gucu_termios_oflag);
@@ -513,5 +616,7 @@ gucu_extra_init_function ()
   scm_c_define_gsubr ("termios-cflag-set!", 2, 0, 0, gucu_termios_cflag_set_x);
   scm_c_define_gsubr ("termios-lflag-set!", 2, 0, 0, gucu_termios_lflag_set_x);
   scm_c_define_gsubr ("termios-cc-set!", 3, 0, 0, gucu_termios_cc_set_x);
- 
+#endif /* ENABLE_TERMIOS */
+
+  scm_c_define_gsubr ("%strwidth", 1, 0, 0, gucu_strwidth);
 }
