@@ -1,7 +1,7 @@
 /*
   type.c
 
-  Copyright 2009, 2010 Free Software Foundation, Inc.
+  Copyright 2009, 2010, 2011 Free Software Foundation, Inc.
 
   This file is part of GNU Guile-Ncurses.
 
@@ -26,7 +26,6 @@
 #include <assert.h>
 #include <errno.h>
 #include <libguile.h>
-#include <libintl.h>
 #include <limits.h>
 #include <stdio.h>
 #include <string.h>
@@ -158,7 +157,7 @@ _scm_xchar_from_cchar (cchar_t * x)
   ret = getcchar (x, wch, &attr, &color_pair, NULL);
 
   if (ret == ERR)
-    scm_misc_error (NULL, gettext ("error unpacking complex char"), SCM_EOL);
+    scm_misc_error (NULL, "error unpacking complex char", SCM_EOL);
 
   /* Strip the color info from attr */
   attr &= A_ATTRIBUTES ^ A_COLOR;
@@ -828,6 +827,13 @@ _scm_from_mevent (MEVENT * me)
      scm_from_int (me->y), scm_from_int (me->z), scm_from_ulong (me->bstate));
 }
 
+SCM
+gucu_is_mevent_p (SCM x)
+{
+  return scm_from_bool (_scm_is_mevent (x));
+}
+
+
 // screen -- in C, a SCREEN *.	In Scheme, a smob that contains that pointer.
 
 int
@@ -878,7 +884,7 @@ print_screen (SCM x, SCM port, scm_print_state * pstate UNUSED)
 
   if (screen == NULL)
     {
-      scm_puts ( gettext ("(freed)"), port);
+      scm_puts ("(freed)", port);
     }
   else
     {
@@ -939,10 +945,9 @@ _scm_from_window (WINDOW * x)
   if (0)
     {
 #ifdef NCURSES_OPAQUE
-      fprintf (stderr, gettext ("Making smob from window\n") );
+      fprintf (stderr, "Making smob from window\n");
 #else
-      fprintf (stderr, gettext ("Making smob from window at %d, %d\n"),
-	       x->_begx, x->_begy);
+      fprintf (stderr, "Making smob from window at %d, %d\n", x->_begx, x->_begy);
 #endif
     }
 
@@ -993,7 +998,7 @@ free_window (SCM x)
       if (win == stdscr)
 	{
 	  endwin ();
-	  fprintf (stderr, gettext ("Freeing stdscr #<window %p>"), (void *) stdscr);
+	  fprintf (stderr, "Freeing stdscr #<window %p>", (void *) stdscr);
 	  delwin (stdscr);
 	  SCM_SET_SMOB_DATA (x, 0);
 	}
@@ -1019,7 +1024,7 @@ print_window (SCM x, SCM port, scm_print_state * pstate UNUSED)
   scm_puts ("#<window ", port);
 
   if (win == 0)
-    scm_puts ( gettext ("(freed)"), port);
+    scm_puts ("(freed)", port);
   else
     {
       if (asprintf (&str, "%p", (void *) win) < 0)
@@ -1047,6 +1052,9 @@ gucu_init_type ()
 
   if (first)
     {
+
+      scm_c_define_gsubr ("mevent?", 1, 0, 0, gucu_is_mevent_p);
+
       screen_tag = scm_make_smob_type ("screen", sizeof (SCREEN *));
       scm_set_smob_print (screen_tag, print_screen);
       scm_c_define_gsubr ("screen?", 1, 0, 0, gucu_is_screen_p);
